@@ -7,6 +7,7 @@ from __future__ import division, print_function, absolute_import
 
 __author__ = "Marek Rudnicki"
 
+__version__ = "0.2"
 
 import os
 import sys
@@ -35,6 +36,7 @@ if 'THlog' in os.environ:
 
 
 import thorns.util
+import thorns.waves
 
 
 from thorns.spikes import (
@@ -95,11 +97,6 @@ from thorns.plotting import (
     plot_sac,
     plot_period_histogram,
     plot_signal,
-    show
+    show,
+    gcf,
 )
-
-
-def gcf():
-    import matplotlib.pyplot as plt
-    fig = plt.gcf()
-    return fig
